@@ -3,7 +3,6 @@ from django.conf import settings
 
 PYBB_TOPIC_PAGE_SIZE = getattr(settings, 'PYBB_TOPIC_PAGE_SIZE', 10)
 PYBB_FORUM_PAGE_SIZE = getattr(settings, 'PYBB_FORUM_PAGE_SIZE', 10)
-PYBB_USERS_PAGE_SIZE = getattr(settings, 'PYBB_USERS_PAGE_SZIE', 20)
 PYBB_AVATAR_WIDTH = getattr(settings, 'PYBB_AVATAR_WIDTH', 80)
 PYBB_AVATAR_HEIGHT = getattr(settings, 'PYBB_AVATAR_HEIGHT',80)
 PYBB_MAX_AVATAR_SIZE = getattr(settings, 'PYBB_MAX_AVATAR_SIZE', 1024*50)
@@ -12,8 +11,6 @@ PYBB_DEFAULT_TIME_ZONE = getattr(settings, 'PYBB_DEFAULT_TIME_ZONE', 3)
 PYBB_SIGNATURE_MAX_LENGTH = getattr(settings, 'PYBB_SIGNATURE_MAX_LENGTH', 1024)
 PYBB_SIGNATURE_MAX_LINES = getattr(settings, 'PYBB_SIGNATURE_MAX_LINES', 3)
 
-PYBB_READ_TIMEOUT = getattr(settings, 'PYBB_READ_TIMEOUT', 3600 * 24 * 7) # seconds
-
 PYBB_DEFAULT_MARKUP = getattr(settings, 'PYBB_DEFAULT_MARKUP', 'bbcode')
 PYBB_FREEZE_FIRST_POST = getattr(settings, 'PYBB_FREEZE_FIRST_POST', False)
 
@@ -52,7 +49,7 @@ PYBB_SMILES = getattr(settings, 'PYBB_SMILES', {
 def smile_it(str):
     s = str
     for smile, url in PYBB_SMILES.items():
-        s = s.replace(smile, '<img src="%s%s%s">' % (settings.MEDIA_URL, PYBB_SMILES_PREFIX, url))
+        s = s.replace(smile, '<img src="%s%s%s" alt="smile" />' % (settings.STATIC_URL, PYBB_SMILES_PREFIX, url))
     return s
 
 PYBB_MARKUP_ENGINES = getattr(settings, 'PYBB_MARKUP_ENGINES', {
@@ -65,6 +62,8 @@ PYBB_QUOTE_ENGINES = getattr(settings, 'PYBB_QUOTE_ENGINES', {
     'markdown': lambda text, username="": '>'+text.replace('\n','\n>').replace('\r','\n>') + '\n'
 })
 
+PYBB_MARKUP = getattr(settings, 'PYBB_MARKUP', 'bbcode')
+
 PYBB_BUTTONS = getattr(settings, 'PYBB_BUTTONS', {})
 #Dict of buttons that will be used, instead of text links if defined
 #Currently supported buttons:
