@@ -1,7 +1,8 @@
 from django.db.models.signals import post_save
+from django.conf import settings
 
 from pybb.subscription import notify_topic_subscribers
-from pybb.models import Post
+from pybb.models import Post, Profile
 from django.contrib.auth.models import User, Permission
 
 
@@ -25,6 +26,8 @@ def user_saved(instance, created, **kwargs):
         return
     instance.user_permissions.add(add_post_permission, add_topic_permission)
     instance.save()
+    if settings.AUTH_PROFILE_MODULE == 'pybb.Profile':
+        Profile(user=instance).save()
 
 def setup_signals():
     post_save.connect(post_saved, sender=Post)
